==> apache-netbeans-java-20.0.301-sources.zip: ide/languages.hcl/src/org/netbeans/modules/languages/hcl/ast/HCLExpression.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
package org.netbeans.modules.languages.hcl.ast;

import java.util.List;
import org.antlr.v4.runtime.CharStreams;
import org.antlr.v4.runtime.CommonTokenStream;
import org.netbeans.modules.languages.hcl.grammar.HCLLexer;
import org.netbeans.modules.languages.hcl.grammar.HCLParser;

/**
 *
 * @author lkishalmi
 */
public abstract class HCLExpression extends HCLElement {

    public static HCLExpression parse(String expr) {
        HCLLexer lexer = new HCLLexer(CharStreams.fromString(expr));
        HCLParser parser = new HCLParser(new CommonTokenStream(lexer));
        return new HCLExpressionFactory().process(parser.expression());
    }
    
    public String toString() {
        return getClass().getSimpleName() + ": " + asString();
    }
    
    public abstract List<? extends HCLExpression> getChildren();
    
    public abstract String asString();
    
    @Override
    public final void accept(Visitor v) {
        if (!v.visit(this)) {
            for (HCLExpression c : getChildren()) {
                if (c != null) {
                    c.accept(v);
                }
            }
        }
    }
}

==> apache-netbeans-java-21.9.9-sources.zip: ide/languages.hcl/src/org/netbeans/modules/languages/hcl/ast/HCLExpression.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
package org.netbeans.modules.languages.hcl.ast;

import java.util.Collections;
import java.util.List;
import org.antlr.v4.runtime.CharStreams;
import org.antlr.v4.runtime.CommonTokenStream;
import org.netbeans.modules.languages.hcl.grammar.HCLLexer;
import org.netbeans.modules.languages.hcl.grammar.HCLParser;

/**
 *
 * @author lkishalmi
 */
public sealed interface HCLExpression extends HCLElement permits
        HCLArithmeticOperation,
        HCLCollection,
        HCLCollection.ObjectElement,
        HCLConditionalOperation,
        HCLForExpression,
        HCLFunction,
        HCLLiteral,
        HCLResolveOperation,
        HCLTemplate,
        HCLVariable {

    public static HCLExpression parse(String expr) {
        HCLLexer lexer = new HCLLexer(CharStreams.fromString(expr));
        HCLParser parser = new HCLParser(new CommonTokenStream(lexer));
        return new HCLExpressionFactory().process(parser.expression());
    }

    default List<? extends HCLExpression> elements() {
        return Collections.emptyList();
    }

    public abstract String asString();

}
